leukemia.test: Gene expression Leukemia test data set from Golub et al....

leukemia.testR Documentation

Gene expression Leukemia test data set from Golub et al. (1999)

Description

Gene expression test data of 7129 genes from 34 patients with acute leukemias (20 in class Acute Lymphoblastic Leukemia and 14 in class Acute Myeloid Leukemia) from the microarray study of Golub et al. (1999).

Usage

leukemia.test

Format

## 'leukemia.test' A data frame with 34 rows and 7130 columns:

...

V7130

class label

<http://wwwprod.broadinstitute.org/cgi-bin/cancer/datasets.cgi>


SIS documentation built on March 14, 2026, 9:07 a.m.