prostate.test: Gene expression Prostate Cancer test data set from Singh et...

prostate.testR Documentation

Gene expression Prostate Cancer test data set from Singh et al. (2002)

Description

Gene expression training data of 12600 genes from 25 patients with prostate tumors and 9 normal specimens from the microarray study of Singh et al. (2002).

Usage

prostate.test

Format

## 'prostate.test' A data frame with 34 rows and 12601 columns:

...

V12601

class label

<http://wwwprod.broadinstitute.org/cgi-bin/cancer/datasets.cgi>


SIS documentation built on March 14, 2026, 9:07 a.m.