prostate.train: Gene expression Prostate Cancer training data set from Singh...

prostate.trainR Documentation

Gene expression Prostate Cancer training data set from Singh et al. (2002)

Description

Gene expression training data of 12600 genes from 52 patients with prostate tumors and 50 normal specimens from the microarray study of Singh et al. (2002).

Usage

prostate.train

Format

## 'prostate.train' A data frame with 102 rows and 12601 columns:

...

V12601

class label

<http://wwwprod.broadinstitute.org/cgi-bin/cancer/datasets.cgi>


SIS documentation built on March 14, 2026, 9:07 a.m.